solve linear least square problem min_x ||A*x-b||
with inequality constraints u%*%x >= co
If A is rank deficient, least norm solution ||mnorm%*%(x-x0)|| is used.
If the parameter mnorm is NULL, it is treated as an identity matrix.
If the vector x0 is NULL, it is treated as 0 vector.
lsi_ln(a, b, u = NULL, co = NULL, rcond = 1e+10, mnorm = NULL, x0 = NULL)solution vector whose attribute 'mes' may contain a message about possible numerical problems
dense matrix A or its QR decomposition
right hand side vector
dense matrix of inequality constraints
right hand side vector of inequality constraints
maximal condition number for determining rank deficient matrix
norm matrix (can be dense or sparse) for which %*% operation with a dense vector is defined
optional vector from which a least norm distance is searched for
lsi, ldp, base::qr