solve linear least square problem (min ||A%%x-b||) with inequality constraints u%%x>=co and equality constraints e%*%x=ce Method: reduce the pb to lsi_ln on the null-space of e
lsie_ln(
a,
b,
u = NULL,
co = NULL,
e = NULL,
ce = NULL,
rcond = 1e+10,
mnorm = NULL,
x0 = NULL
)solution vector whose attribute 'mes' may contain a message about possible numerical problems
dense matrix A or its QR decomposition
right hand side vector
dense matrix of inequality constraints
right hand side vector of inequality constraints
dense matrix of equality constraints
right hand side vector of equality constraints
maximal condition number for determining rank deficient matrix
matrix to be used to minimize the norm ||mnorm%*%x|| in case of under-dermined system. If mnorm is NULL (default), it is
vector from which minimal norm should be searched when required
lsi_ln